==> jmb.tools-0.4.tar.gz: jmb.tools-0.4/jmb/tools/kick/__init__.py <==
import click

from . import kickstart


@click.command('kick')
@click.argument('prj-type', required=False)
@click.argument('prj-name', required=False)
@click.argument('mod-name', required=False)
@click.option('--list', '-l', help="list available types", is_flag=True)
@click.option('--force-exists', '-e', help="untar even if a dir with same name already exists",
              is_flag=True, default=False)
@click.option('--local', '-L', help="use local pypi (http://localhost/pypi)", is_flag=True)
@click.option('--skeleton-file', '-f',
              help="use SKELETON_FILE as skeleton (must be tar file)")
@click.option('--bootstrap', '-B', help="lancia 'python bootstrap -d'", is_flag=True)
@click.option('--buildout', '-b', help="lancia bin/buildout -N (implica -B e -m)", is_flag=True)
@click.option('--go', '-g', help="lancia jmb-go", is_flag=True)
@click.option('--mercurial', '-m', help="inizilizza un repo mercurial", is_flag=True)
@click.option('--debug', '-D', help="show variable internal to jmb-start", is_flag=True)
@click.option('--no-cms', '-x', help="disable cms", is_flag=True)
@click.option('--all', '-a', help="-xbgmv", is_flag=True)
@click.option('--prj-dir', '-d', help=" create the project within dir (eg: start -d /tmp -t cms...)")
@click.option('-k', '--key-generation', help="generate a key and exit", is_flag=True)
def kick(prj_type, prj_name, mod_name, list, force_exists, local, skeleton_file, bootstrap, buildout, go, mercurial, debug,
          no_cms, all, prj_dir, key_generation):
    "Start a new project/app"
    class Opts:
        pass

    o = Opts()
    o.type = prj_type
    o.force_exists = force_exists
    o.list = list
    o.local = local
    o.skeleton_file = skeleton_file
    o.bootstrap = bootstrap
    o.buildout = buildout
    o.go = go
    o.mercurial = mercurial
    o.debug = debug
    o.no_cms = no_cms
    o.all = all
    o.key_generation = key_generation
    o.prj_dir = prj_dir
    o.verbose = True
    args = []
    if prj_name:
        args = [prj_name]
    if mod_name:
        args += [mod_name]

    kickstart.cli(o, args)

==> jmb.tools-0.7.1.tar.gz: jmb.tools-0.7.1/jmb/tools/kick/__init__.py <==
import click

from . import kickstart


@click.command('kick')
@click.argument('prj-type', required=False)
@click.argument('prj-name', required=False)
@click.argument('mod-name', required=False)
@click.option('--list', '-l', help="list available types", is_flag=True)
@click.option('--force-exists', '-e', help="untar even if a dir with same name already exists",
              is_flag=True, default=False)
@click.option('--local', '-L', help="use local pypi (http://localhost/pypi)", is_flag=True)
@click.option('--skeleton-file', '-f',
              help="use SKELETON_FILE as skeleton (must be tar file)")
@click.option('--bootstrap', '-B', help="lancia 'python bootstrap -d'", is_flag=True)
@click.option('--buildout', '-b', help="lancia bin/buildout -N (implica -B e -m)", is_flag=True)
@click.option('--go', '-g', help="lancia jmb-go", is_flag=True)
@click.option('--mercurial', '-m', help="inizilizza un repo mercurial", is_flag=True)
@click.option('--debug', '-D', help="show variable internal to jmb-start", is_flag=True)
@click.option('--no-cms', '-x', help="disable cms", is_flag=True)
@click.option('--all', '-a', help="-xbgmv", is_flag=True)
@click.option('--prj-dir', '-d', help=" create the project within dir (eg: start -d /tmp -t cms...)")
@click.option('-k', '--key-generation', help="generate a key and exit", is_flag=True)
def kick(
    prj_type, prj_name, mod_name, list, force_exists, local, skeleton_file, bootstrap, buildout, go, mercurial, debug,
        no_cms, all, prj_dir, key_generation):
    "Start a new project/app"
    class Opts:
        pass

    o = Opts()
    o.type = prj_type
    o.force_exists = force_exists
    o.list = list
    o.local = local
    o.skeleton_file = skeleton_file
    o.bootstrap = bootstrap
    o.buildout = buildout
    o.go = go
    o.mercurial = mercurial
    o.debug = debug
    o.no_cms = no_cms
    o.all = all
    o.key_generation = key_generation
    o.prj_dir = prj_dir
    o.verbose = True
    args = []
    if prj_name:
        args = [prj_name]
    if mod_name:
        args += [mod_name]

    kickstart.cli(o, args)
